#script to calculate continental temperatures (surface air temperatures over continents), calculated using ssts and surface air temperatures for 1000 years (from yearly snapshots), for vegetation sensitivity, using LeHir albedo
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
from matplotlib.gridspec import GridSpec
from netCDF4 import Dataset
import sys
import numpy.ma as ma

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]



Namevarlong=np.array(['surface air temperature [°C]', 'SST [°C]', 'land fraction'])


namesp2s=np.array(['tsur','sst','frlnd'])   

vegname=['early','middle','late']
Var_mean=np.zeros((len(vegname),len(namesp2s)))

#create grid for maps
lon2d, lat2d = np.meshgrid(lon, lat)

x=lon2d
y=lat2d


nc_f_bare = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_LeHir_albedo_bare/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'
nc_f_tree = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_LeHir_albedo_treecover/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'


data_bare=Dataset(nc_f_bare, 'r')
ts_bare =data_bare.variables['ts'][0:1000,:,:]
ts_bare=np.mean(ts_bare,axis=0)

data_bare=Dataset(nc_f_bare, 'r')
sst_bare =data_bare.variables['sst'][0:1000,:,:]
sst_bare=np.mean(sst_bare,axis=0)
          
newdatabare=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndbare=newdatabare.reshape((24,16))
     

Varbare=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndbare[m,n]==0:
            Varbare[m,n]=1000
        else:
            Varbare[m,n]=(ts_bare[m,n]-(1-frlndbare[m,n])*sst_bare[m,n])/frlndbare[m,n]
                
Varbare=np.ma.masked_object(Varbare,1000)
                
Varbare_mean_zonal=np.sum(Varbare*frlndbare,axis=1)/np.sum(frlndbare,axis=1)#zonal mean
#print Var_mean_zonal
Landbare_mean_zonal=np.mean(frlndbare,axis=1)
Varbare_mean_zonal_weight=Varbare_mean_zonal[:]*Landbare_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1bare=np.sum(np.cos(pi_frac)*Landbare_mean_zonal)
Varbare_mean_0=np.sum(Varbare_mean_zonal_weight,axis=0)/weightsum1bare #mean
##############################################################################################
data_tree=Dataset(nc_f_tree, 'r')
ts_tree =data_tree.variables['ts'][0:1000,:,:]
ts_tree=np.mean(ts_tree,axis=0)

data_tree=Dataset(nc_f_tree, 'r')
sst_tree =data_tree.variables['sst'][0:1000,:,:]
sst_tree=np.mean(sst_tree,axis=0)

newdatatree=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndtree=newdatatree.reshape((24,16))
  
Vartree=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndtree[m,n]==0:
            Vartree[m,n]=1000
        else:
            Vartree[m,n]=(ts_tree[m,n]-(1-frlndtree[m,n])*sst_tree[m,n])/frlndtree[m,n]
                
Vartree=np.ma.masked_object(Vartree,1000)
                
Vartree_mean_zonal=np.sum(Vartree*frlndtree,axis=1)/np.sum(frlndtree,axis=1)#zonal mean
#print Var_mean_zonal
Landtree_mean_zonal=np.mean(frlndtree,axis=1)
Vartree_mean_zonal_weight=Vartree_mean_zonal[:]*Landtree_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1tree=np.sum(np.cos(pi_frac)*Landtree_mean_zonal)
Vartree_mean_0=np.sum(Vartree_mean_zonal_weight,axis=0)/weightsum1tree #mean

               
print Varbare_mean_0
print Vartree_mean_0
