#script to calculate continental temperatures (surface air temperatures over continents), calculated using ssts and surface air temperatures for 1000 years (from yearly snapshots), for continental sensitivity
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
from matplotlib.gridspec import GridSpec
from netCDF4 import Dataset
import sys
import numpy.ma as ma

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]


Namevarlong=np.array(['surface air temperature [°C]', 'SST [°C]', 'land fraction'])


namesp2s=np.array(['ts','sst','frlnd'])   

vegname=['early','middle','late']
Var_mean=np.zeros((len(vegname),len(namesp2s)))

#create grid for maps
lon2d, lat2d = np.meshgrid(lon, lat)

x=lon2d
y=lat2d


nc_f_early = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_415Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_bare/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'
nc_f_middle = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_bare/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'
nc_f_late = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_360Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_bare_newcontconfig/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'

data_early=Dataset(nc_f_early, 'r')
ts_early =data_early.variables['ts'][0:1000,:,:]
ts_early=np.mean(ts_early,axis=0)

sst_early =data_early.variables['sst'][0:1000,:,:]
sst_early=np.mean(sst_early,axis=0)
          
newdataearly=np.loadtxt('ModelOutput_p2s_frlnd_415.dat')
frlndearly=newdataearly.reshape((24,16))

     

Varearly=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndearly[m,n]==0:
            Varearly[m,n]=1000
        else:
            Varearly[m,n]=(ts_early[m,n]-(1-frlndearly[m,n])*sst_early[m,n])/frlndearly[m,n]
                
Varearly=np.ma.masked_object(Varearly,1000)
                
Varearly_mean_zonal=np.sum(Varearly*frlndearly,axis=1)/np.sum(frlndearly,axis=1)#zonal mean
#print Var_mean_zonal
Landearly_mean_zonal=np.mean(frlndearly,axis=1)
Varearly_mean_zonal_weight=Varearly_mean_zonal[:]*Landearly_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1early=np.sum(np.cos(pi_frac)*Landearly_mean_zonal)
Varearly_mean_0=np.sum(Varearly_mean_zonal_weight,axis=0)/weightsum1early #mean
##############################################################################################
data_middle=Dataset(nc_f_middle, 'r')
ts_middle =data_middle.variables['ts'][0:1000,:,:]
ts_middle=np.mean(ts_middle,axis=0)

data_middle=Dataset(nc_f_middle, 'r')
sst_middle =data_middle.variables['sst'][0:1000,:,:]
sst_middle=np.mean(sst_middle,axis=0)

newdatamiddle=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndmiddle=newdatamiddle.reshape((24,16))
  
Varmiddle=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndmiddle[m,n]==0:
            Varmiddle[m,n]=1000
        else:
            Varmiddle[m,n]=(ts_middle[m,n]-(1-frlndmiddle[m,n])*sst_middle[m,n])/frlndmiddle[m,n]
                
Varmiddle=np.ma.masked_object(Varmiddle,1000)
                
Varmiddle_mean_zonal=np.sum(Varmiddle*frlndmiddle,axis=1)/np.sum(frlndmiddle,axis=1)#zonal mean
#print Var_mean_zonal
Landmiddle_mean_zonal=np.mean(frlndmiddle,axis=1)
Varmiddle_mean_zonal_weight=Varmiddle_mean_zonal[:]*Landmiddle_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1middle=np.sum(np.cos(pi_frac)*Landmiddle_mean_zonal)
Varmiddle_mean_0=np.sum(Varmiddle_mean_zonal_weight,axis=0)/weightsum1middle #mean

##############################################################################################
data_late=Dataset(nc_f_late, 'r')
ts_late =data_late.variables['ts'][0:1000,:,:]
ts_late=np.mean(ts_late,axis=0)

data_late=Dataset(nc_f_late, 'r')
sst_late =data_late.variables['sst'][0:1000,:,:]
sst_late=np.mean(sst_late,axis=0)

newdatalate=np.loadtxt('ModelOutput_p2s_frlnd_360.dat')
frlndlate=newdatalate.reshape((24,16))

Varlate=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndlate[m,n]==0:
            Varlate[m,n]=1000
        else:
            Varlate[m,n]=(ts_late[m,n]-(1-frlndlate[m,n])*sst_late[m,n])/frlndlate[m,n]
                
Varlate=np.ma.masked_object(Varlate,1000)
                
Varlate_mean_zonal=np.sum(Varlate*frlndlate,axis=1)/np.sum(frlndlate,axis=1)#zonal mean
Landlate_mean_zonal=np.mean(frlndlate,axis=1)
Varlate_mean_zonal_weight=Varlate_mean_zonal[:]*Landlate_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1late=np.sum(np.cos(pi_frac)*Landlate_mean_zonal)
Varlate_mean_0=np.sum(Varlate_mean_zonal_weight,axis=0)/weightsum1late #mean
               
print Varearly_mean_0
print Varmiddle_mean_0
print Varlate_mean_0