# -*- coding: utf-8 -*-
import numpy             as np
import matplotlib        as mpl
import matplotlib.pyplot as plt

import convert

def convertToRGBA(colormap, value):
    return colormap(value)

def convertToRGB(colormap, value):
    rgba  = convertToRGBA(colormap, value)
    return convert.rgba_to_rgb(rgba)
    
def convertToHEX(colormap, value):
    rgba  = convertToRGBA(colormap, value)
    return convert.rgba_to_hex(rgba)
    
def createGradient(cmap, unit, start=0, end=1, limit=256, output=False):
    """
    This function takes a color palette and extracts as many different colors 
    as are specified under 'limit'. The 'start' and 'end' value indicate the 
    color range of the extracted colors. To use all colors, just set one value 
    to 0 and the other to 1. To get the colors in reverse order, just switch 
    the values. The colors can be returned in three different units: 'rgba', 
    'rgb' and 'hex'.
    
    Color palettes are free available via matplotlib (colormaps).
    Sample images:
        https://mpl.org/examples/color/colormaps_reference.html

    @author: FuchsS
    """
    colors = []
    
    gradient = np.linspace(start, end, limit)
    for value in gradient:
        if unit.lower() == 'rgb':
            color = convertToRGB(cmap, value)
        elif unit.lower() == 'rgba':
            color = convertToRGBA(cmap, value)
        else:
            color = convertToHEX(cmap, value)        
        colors.append(color)

    if(output):
        print("Colors:\n{}\n").format(colors)
        plt.figure()
        if start > end:
            rgba = createGradient(cmap=cmap, unit='rgba', start=end,   end=start, limit=limit, output=False)
        else:
            rgba = createGradient(cmap=cmap, unit='rgba', start=start, end=end,   limit=limit, output=False)
        printMap = mpl.colors.LinearSegmentedColormap.from_list("printMap", rgba)
        gradient = np.vstack( (gradient, gradient) )
        plt.imshow(gradient, aspect='auto', cmap=printMap)
        plt.axis('off')
        plt.show()
        
    return colors