#This script creates Fig.6 of 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
import numpy.ma as ma
from matplotlib.patches import Polygon
from matplotlib.pyplot import text


degree_sign= u'\N{DEGREE SIGN}'

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))
weightsum_north_p2=np.sum(np.cos(pi_frac)[20:24])

lonlatmomdata=np.loadtxt('ModelOutput_isis_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[194:29]
lat0mom=lonlatmomdata[98:145]
latmidmom=lonlatmomdata[146:194]

pi_frac_mom=(np.pi/180)*latmidmom[:]

weightsum_mom=np.sum(np.cos(pi_frac_mom))

weightsum_north_mom=np.sum(np.cos(pi_frac_mom)[40:48])

oblname=['24p5']

nameisish=np.array(['con_g'])       

Namevarlong=np.array(['ice fraction'])

count=np.zeros(8)
#create grid for maps
lon2d, lat2d = np.meshgrid(lon,lat)
x=lon2d
y=lat2d
        
#ice fraction
newdata=np.loadtxt('ModelOutput_isish_24p5_3600s.dat')
newdata=newdata.reshape((3802,48,96))
newdata=np.ma.masked_equal(newdata,-1)
Varnorth=newdata[2800:3800,40:48,:] 
Varnorth_zonal_mean=np.mean(Varnorth,axis=2)
Var_mean_zonal_weight=Varnorth_zonal_mean[:]*np.cos(pi_frac_mom)[40:48]#weighted zonal mean 
Var_mean_north_ice=np.sum(Var_mean_zonal_weight,axis=1)/weightsum_north_mom #mean             
###############################################################################
#maximum Arctic overturning
newdata=np.loadtxt('ModelOutput_momh_24p5_3600s.dat')
newdata=newdata.reshape((3802,25,48))
newdata=np.ma.masked_equal(newdata,-1)
Varnorth=newdata[2800:3800,12:20,40:48] 
MaxVarNorth=np.max(Varnorth,axis=1)   
MaxVarNorth=np.max(MaxVarNorth,axis=1)      
###############################################################################
#surface air temperature
newdata=np.loadtxt('ModelOutput_p2h_24p5_3600s.dat')
newdata=newdata.reshape((3802,24,16))
Var=newdata[2800:3800,:,:] 
Var_zonal_mean=np.mean(Var,axis=2)
Var_mean_zonal_weight=Var_zonal_mean[:]*np.cos(pi_frac)#weighted zonal mean 
Var_mean=np.sum(Var_mean_zonal_weight,axis=1)/weightsum#mean   
###############################################################################
#Arctic temperature
newdata=np.loadtxt('ModelOutput_p2h_24p5_3600s.dat')
newdata=newdata.reshape((3802,24,16))
Var=newdata[2800:3800,20:24,:] 
Var_zonal_mean_north=np.mean(Var,axis=2)
Var_mean_zonal_weight_north=Var_zonal_mean_north[:]*np.cos(pi_frac[20:24])#weighted zonal mean 
Var_mean_north=np.sum(Var_mean_zonal_weight_north,axis=1)/weightsum_north_p2#mean 
       
fig, axes = plt.subplots(nrows=3, ncols=1,figsize=(12,12))
ax1=axes[0]
ax2=axes[1]
ax3=axes[2]
ax2a=ax2.twinx()
       
ax1.set_title('(a)',x=-0.1,y=0.95,fontsize=12)
time=np.arange(0,1000)
ax1.plot(time,Var_mean,'k-')
ax1.set_xlabel('time [yrs]',color='k',fontsize='12')

major_xticks=np.arange(0,1000,100)
minor_xticks=np.arange(0,1000,50)
# Specify tick label size
ax1.tick_params(axis = 'both', which = 'major', labelsize = 12)
ax1.tick_params(axis = 'both', which = 'minor', labelsize = 3)
ax1.tick_params(axis='both', top='on', labelbottom='off', labeltop='on')
# Suppress minor tick labels
ax1.set_xticks(minor_xticks, minor = True)

ax1.set_ylabel('Global mean temperature ['+degree_sign+'C]',color='k',fontsize='12')
ax1.set_ylim(21.43,21.7)
ax1.vlines(x=190, ymin=21.43, ymax=21.7, color = 'r')
#ax1.text(212,21.55, "warm mode", rotation=90, verticalalignment='center',color='r')
ax1.vlines(x=300, ymin=21.43, ymax=21.7, color = 'b')
#ax1.text(322,21.55, "cold mode", rotation=90, verticalalignment='center', color='b')

ax2.set_title('(b)',x=-0.1,y=0.95,fontsize=12)
ax2.plot(time,Var_mean_north,'k-')
ax2.set_xlabel('time [yrs]',color='k',fontsize='12')
ax2.set_ylabel('Arctic temperature ['+degree_sign+'C]',color='k',fontsize='12')
ax2.set_ylim(3.3,5.3)

ax2.vlines(x=190, ymin=3.3, ymax=5.3, color = 'r')
ax2.vlines(x=300, ymin=3.3, ymax=5.3, color = 'b')

ax2a.plot(time,Var_mean_north_ice,color='grey', linestyle='--')
for tl in ax2a.get_yticklabels():
    tl.set_color('grey') 
ax2a.set_ylim(-0.005,0.09)
ax2a.tick_params(axis = 'both', which = 'major', labelsize = 12)

major_xticks=np.arange(0,1000,100)
minor_xticks=np.arange(0,1000,50)
ax2.tick_params(axis = 'both', which = 'major', labelsize = 12)
ax2.tick_params(axis = 'both', which = 'minor', labelsize = 3)
# Suppress minor tick labels
ax2.set_xticks(minor_xticks, minor = True)
ax2.tick_params(axis='both', top='on', labelbottom='off', labeltop='off')
ax2.set_xlabel('time [yrs]',color='k',fontsize='12')
ax2a.set_ylabel('Arctic ice fraction', color='grey',fontsize='12')

ax3.set_title('(c)',x=-0.1,y=0.95,fontsize=12)
time=np.arange(0,1000)
ax3.plot(time,MaxVarNorth,'k-')
ax3.set_xlabel('time [yrs]',color='k',fontsize='12')

major_xticks=np.arange(0,1000,100)
minor_xticks=np.arange(0,1000,50)
# Specify tick label size
ax3.tick_params(axis = 'both', which = 'major', labelsize = 12)
ax3.tick_params(axis = 'both', which = 'minor', labelsize = 3)
# Suppress minor tick labels
ax3.set_xticks(minor_xticks, minor = True)
ax3.set_ylim(3,7.3)
ax3.set_ylabel('Maximum arctic overturning [Sv]',color='k',fontsize='12')

ax3.vlines(x=190, ymin=3, ymax=7.3, color = 'r')
ax3.vlines(x=300, ymin=3, ymax=7.3, color = 'b')

plt.subplots_adjust(wspace=0, hspace=0)

fig.savefig('Modes.pdf', format='pdf',bbox_inches='tight') 



