#This script reads out model data and writes it in .dat files. The output files are then used to generate Fig. 8 in 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
from netCDF4 import Dataset
#from newsavetxt import *
#import matplotlib.pyplot as plt
#from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
#from matplotlib.backends.backend_pdf import PdfPages
import sys
import numpy.ma as ma

np.set_printoptions(threshold=sys.maxint)

#getting continent contours
nc_f_380_cont = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O24p5_E0p069_P315_bare_3600s/topog.dta.nc'


nc_f_cont=[nc_f_380_cont]
cont=[380]
contname=['380']


datacont=nc_f_380_cont
nc_fid = Dataset(datacont, 'r') 
cont_t=nc_fid.variables['dht'][0,:,:]#land ocean mask grid center
cont_u=nc_fid.variables['dhu'][0,:,:]#land ocean mask grid border

for i in range(0,48):
  for j in range (0,96):
      if cont_t[i,j] == 2500:
          cont_t[i,j]=1
      else:
          cont_t[i,j]=0
            
      if cont_u[i,j] == 2500:
          cont_u[i,j]=1
      else:
          cont_u[i,j]=0

tab='\n'
comment='#'
filename='ModelOutput_continents380.dat'
with file(filename,'w') as outfile:
    outfile.write(comment+'continent contours center'+tab)
    np.savetxt(outfile,cont_t,fmt='%12.3f')
    outfile.write(comment+'continent contours borders'+tab)
    np.savetxt(outfile,cont_u,fmt='%12.6f')



number=['2993','3043','3103','3193']

#MOM variables
for i in range(len(number)):
    snapshotsmom='/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O24p5_E0p069_P315_bare_3600s/snapshots.00'+number[i]+'.01.01.dta.nc'

    nc_f_smom=snapshotsmom
    nc_fid_smom = Dataset(nc_f_smom, 'r')        
        
    temp = nc_fid_smom.variables['temp'][:,:,:,:]#quantity is defined at the grid centers
    temp0=temp[:,0,:,:]#surface value
    temp0=np.mean(temp0,axis=0)#time mean
    temp0=np.ma.filled(temp0,fill_value=1000)
        
    salt = nc_fid_smom.variables['salt'][:,:,:,:]#quantity is defined at the grid centers
    salt0=salt[:,0,:,:]#surface value
    salt0=np.mean(salt0,axis=0)#time mean
    salt0=np.ma.filled(salt0,fill_value=1000)

    hmxl = nc_fid_smom.variables['hmxl'][:,:,:]#quantity is defined at the grid centers
    hmxl=np.max(hmxl,axis=0)#time mean
    hmxl=np.ma.filled(hmxl,fill_value=-1)

    eta = nc_fid_smom.variables['eta'][:,:,:]#quantity is defined at the grid centers
    eta=np.mean(eta,axis=0)#time mean
    eta=np.ma.filled(eta,fill_value=-1000)

    u = nc_fid_smom.variables['u'][:,:,:,:]#quantity is defined at the grid centers
    u0=u[:,0,:,:]#surface value
    u0=np.mean(u0,axis=0)#time mean
    u0=np.ma.filled(u0,fill_value=1000)

    v = nc_fid_smom.variables['v'][:,:,:,:]#quantity is defined at the grid centers
    v0=v[:,0,:,:]#surface value
    v0=np.mean(v0,axis=0)#time mean
    v0=np.ma.filled(v0,fill_value=1000)

        
    arraymoms=np.array([temp0,salt0,hmxl,eta,u0,v0])
    namesmoms=np.array(['temp0','salt0','hmxl','eta','u0','v0'])  
   
    tab='\n'
    comment='#'
    filename='ModelOutput_smom'+number[i]+'_3600s.dat'
    with file(filename,'w') as outfile:
        for k in range(len(arraymoms)):
            outfile.write(comment+namesmoms[k]+tab)
            np.savetxt(outfile,arraymoms[k],fmt='%12.6f')
       
#MOM grid
nc_f_smom='/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O24p5_E0p069_P315_bare_3600s/snapshots.003003.01.01.dta.nc'
nc_fid_smom = Dataset(nc_f_smom, 'r') 
lonsmom=nc_fid_smom.variables['xu_i'][:]#longitudes of the grid's borders
lonsmom=np.concatenate((np.array([0]),lonsmom))#add longitude 0 to the lonigtude array
lonmidsmom=nc_fid_smom.variables['xt_i'][:]#longitudes of the grid's center
latsmom=nc_fid_smom.variables['yu_j'][:]#latitudes of the grid's borders
latsmom=np.concatenate((np.array([-90]),latsmom))#add longitude 90 to the lonigtude array      
latmidsmom=nc_fid_smom.variables['yt_j'][:]#latitudes of the grid's centers(needed to calculate cosine fractions)
depthsmom=nc_fid_smom.variables['zw_k'][:]
timesmom=nc_fid_smom.variables['Time'][:]       
arraymomslonlat=np.array([lonsmom,lonmidsmom,latsmom,latmidsmom,depthsmom])
namesmomslonlat=np.array(['lonsmom','lonmidsmom','latsmom','latmidsmom','depthsmom']) 
 
filename='ModelOutputImpact_smom_lonlat.dat'
with file(filename,'w') as outfile:
    for k in range(len(arraymomslonlat)):
        outfile.write(comment+namesmomslonlat[k]+tab)
        np.savetxt(outfile,arraymomslonlat[k],fmt='%12.6f')
            
#ISIS
for i in range(len(number)):
    snapshotsisis='/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O24p5_E0p069_P315_bare_3600s/snapshots_isis.00'+number[i]+'.01.01.dta.nc'

    nc_f_sisis=snapshotsisis
    nc_fid_sisis = Dataset(nc_f_sisis, 'r')        
        
    cong = nc_fid_sisis.variables['con_g'][:,0,:,:]#quantity is defined at the grid centers
    cong0=np.max(cong,axis=0)#time mean
    cong0=np.ma.filled(cong0,fill_value=-1)  

    arrayisis=np.array([cong0])
    namesisis=np.array(['cong'])
        
    tab='\n'
    comment='#'
    filename='ModelOutput_sisis'+number[i]+'_3600s.dat'
    with file(filename,'w') as outfile:
        outfile.write(comment+'cong'+tab)
        np.savetxt(outfile,cong0,fmt='%12.6f')
          
