#This script creates Fig. 8, 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
import numpy.ma as ma
from matplotlib.patches import Polygon

import matplotlib.colors as colors
from matplotlib.mlab import bivariate_normal
import matplotlib.colors as cl

from gradient import createGradient

cmap_ferretrainbow = createGradient(cmap=plt.cm.hsv_r,   unit='rgba', start=0.2,  end=1,   limit=16, output=False)

colormap_ferretrainbow = cl.LinearSegmentedColormap.from_list("printMap", cmap_ferretrainbow)

cmaplist_rainbow = [colormap_ferretrainbow(i) for i in range(colormap_ferretrainbow.N)]

cmap = colormap_ferretrainbow.from_list('Custom cmap', cmaplist_rainbow, colormap_ferretrainbow.N)

cmap_hmxl = createGradient(cmap=plt.cm.hsv_r,   unit='rgba', start=0.45,  end=1,   limit=16, output=False)

colormap_hmxl = cl.LinearSegmentedColormap.from_list("printMap", cmap_hmxl)

lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]
    
namesp2h=np.array(['temp0','salt0','hmxl','eta','u0','v0'])
     
#create grid for maps
lon2d, lat2d = np.meshgrid(lon0mom,lat0mom)
x=lon2d
y=lat2d

lon2dcont, lat2dcont = np.meshgrid(lonmidmom, latmidmom)
xcont=lon2dcont
ycont=lat2dcont

lon2dcont, lat2dcont = np.meshgrid(lonmidmom*(np.pi/180), latmidmom*(np.pi/180))
xcontpi=lon2dcont
ycontpi=lat2dcont

modename=['2993','3043','3103','3193']
        
newdata=np.loadtxt('ModelOutput_smom2993_3600s.dat')
newdata=newdata.reshape((6,48,96))
sst2993=newdata[0,:,:]
sss2993=newdata[1,:,:]
hmxl2993=newdata[2,:,:]
eta2993=newdata[3,:,:]
u02993=newdata[4,:,:]
v02993=newdata[5,:,:]
    
sst2993=np.ma.masked_equal(sst2993,1000)
sss2993=np.ma.masked_equal(sss2993,1000)
hmxl2993=np.ma.masked_equal(hmxl2993,-1)
hmxl2993=hmxl2993/100
eta2993=np.ma.masked_equal(eta2993,-1000)
u02993=np.ma.masked_equal(u02993,1000)
v02993=np.ma.masked_equal(v02993,1000)


icedata=np.loadtxt('ModelOutput_sisis2993_3600s.dat')
icedata=icedata.reshape((1,48,96))
cong2993=icedata[0,:,:]
    
cong2993=np.ma.masked_equal(cong2993,-1)

newdata=np.loadtxt('ModelOutput_smom3043_3600s.dat')
newdata=newdata.reshape((6,48,96))
sst3043=newdata[0,:,:]
sss3043=newdata[1,:,:]
hmxl3043=newdata[2,:,:]
eta3043=newdata[3,:,:]
u03043=newdata[4,:,:]
v03043=newdata[5,:,:]
    
sst3043=np.ma.masked_equal(sst3043,1000)
sss3043=np.ma.masked_equal(sss3043,1000)
hmxl3043=np.ma.masked_equal(hmxl3043,-1)
hmxl3043=hmxl3043/100
eta3043=np.ma.masked_equal(eta3043,-1000)
u03043=np.ma.masked_equal(u03043,1000)
v03043=np.ma.masked_equal(v03043,1000)

icedata=np.loadtxt('ModelOutput_sisis3043_3600s.dat')
icedata=icedata.reshape((1,48,96))
cong3043=icedata[0,:,:]
    
cong3043=np.ma.masked_equal(cong3043,-1)

newdata=np.loadtxt('ModelOutput_smom3103_3600s.dat')
newdata=newdata.reshape((6,48,96))
sst3103=newdata[0,:,:]
sss3103=newdata[1,:,:]
hmxl3103=newdata[2,:,:]
eta3103=newdata[3,:,:]
u03103=newdata[4,:,:]
v03103=newdata[5,:,:]
    
sst3103=np.ma.masked_equal(sst3103,1000)
sss3103=np.ma.masked_equal(sss3103,1000)
hmxl3103=np.ma.masked_equal(hmxl3103,-1)
hmxl3103=hmxl3103/100
eta3103=np.ma.masked_equal(eta3103,-1000)
u03103=np.ma.masked_equal(u03103,1000)
v03103=np.ma.masked_equal(v03103,1000)

icedata=np.loadtxt('ModelOutput_sisis3103_3600s.dat')
icedata=icedata.reshape((1,48,96))
cong3103=icedata[0,:,:]
    
cong3103=np.ma.masked_equal(cong3103,-1)

newdata=np.loadtxt('ModelOutput_smom3193_3600s.dat')
newdata=newdata.reshape((6,48,96))
sst3193=newdata[0,:,:]
sss3193=newdata[1,:,:]
hmxl3193=newdata[2,:,:]
eta3193=newdata[3,:,:]
u03193=newdata[4,:,:]
v03193=newdata[5,:,:]
    
sst3193=np.ma.masked_equal(sst3193,1000)
sss3193=np.ma.masked_equal(sss3193,1000)
hmxl3193=np.ma.masked_equal(hmxl3193,-1)
hmxl3193=hmxl3193/100
eta3193=np.ma.masked_equal(eta3193,-1000)
u03193=np.ma.masked_equal(u03193,1000)
v03193=np.ma.masked_equal(v03193,1000)

icedata=np.loadtxt('ModelOutput_sisis3193_3600s.dat')
icedata=icedata.reshape((1,48,96))
cong3193=icedata[0,:,:]
    
cong3193=np.ma.masked_equal(cong3193,-1)
 ############################################################################################   

    
fig, axes = plt.subplots(nrows=4, ncols=3,figsize=(10,10))
ax1a=axes[0,0]
ax1b=axes[0,1]
ax1c=axes[0,2]
ax2a=axes[1,0]
ax2b=axes[1,1]
ax2c=axes[1,2]
ax3a=axes[2,0]
ax3b=axes[2,1]
ax3c=axes[2,2]
ax4a=axes[3,0]
ax4b=axes[3,1]
ax4c=axes[3,2]

#warm mode
fig.subplots_adjust(hspace=0.4,wspace=0.4)
#SSS, ice margin
m = Basemap(ax=ax1a,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,sss2993,latlon=True,cmap=colormap_ferretrainbow,vmin=30,vmax=35)
m.contour(xcont,ycont,cong2993,latlon=True,colors='k',levels=[0.1])
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax1a.set_ylabel('warm mode',rotation=0, size='large',x=-0.2,y=0.48, labelpad=90)
ax1a.set_xlabel('SSS and ice margin',rotation=0, size='large',labelpad=-160)
ax1a.set_title('(a)',x=-0.1,y=1.1,fontsize=8)

#surface vel. and eta
m = Basemap(ax=ax1b,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,eta2993,latlon=True,cmap=colormap_ferretrainbow,vmin=-350,vmax=160)

u_v=v02993*np.sin(xcontpi)
v_v=-v02993*np.cos(xcontpi)

u_u=-u02993*np.cos(ycontpi)*np.cos(xcontpi)
v_u=-u02993*np.cos(ycontpi)*np.sin(xcontpi)

u=u_v+u_u
v=v_u+v_v

u_norm=u/np.sqrt(u**2+v**2)
v_norm=v/np.sqrt(u**2+v**2)

length_u=np.sqrt(u02993**2+v02993**2)

m.quiver(xcont[::,::3],ycont[::,::3],u_norm[::,::3]*length_u[::,::3],v_norm[::,::3]*length_u[::,::3],latlon=True,scale=300,headlength=3,headaxislength=2)

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax1b.set_xlabel('Surf. velocity and $\eta$',rotation=0, size='large',labelpad=-160)
ax1b.set_title('(b)',x=-0.1,y=1.1,fontsize=8)

#mixed layer
m = Basemap(ax=ax1c,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,hmxl2993,latlon=True,cmap=colormap_hmxl,vmin=0,vmax=3300)
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax1c.set_xlabel('Mixed layer depth',rotation=0, size='large',labelpad=-160)
ax1c.set_title('(c)',x=-0.1,y=1.1,fontsize=8)

######################################################################################################################################
#transition warm to cold
#SSS, ice margin
m = Basemap(ax=ax2a,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,sss3043,latlon=True,cmap=colormap_ferretrainbow,vmin=30,vmax=35)
m.contour(xcont,ycont,cong3043,latlon=True,colors='k',levels=[0.1])

a00,b00=m(359.5,78.75)
a0,b0=m(0.5,78.75)

a=[a00,a0]
b=[b00,b0]

m.plot(a,b,'k-')

a00,b00=m(350,82)
a0,b0=m(1,83)

a=[a00,a0]
b=[b00,b0]

m.plot(a,b,'k-')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

#surface velocity and eta
ax2a.set_ylabel('transition \n warm to cold',rotation=0, size='large',x=-0.2,y=0.48, labelpad=90)
ax2a.set_title('(d)',x=-0.1,y=1.1,fontsize=8)

m = Basemap(ax=ax2b,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,eta3043,latlon=True,cmap=colormap_ferretrainbow,vmin=-350,vmax=160)
u_v=v03043*np.sin(xcontpi)
v_v=-v03043*np.cos(xcontpi)

u_u=-u03043*np.cos(ycontpi)*np.cos(xcontpi)
v_u=-u03043*np.cos(ycontpi)*np.sin(xcontpi)

u=u_v+u_u
v=v_u+v_v

u_norm=u/np.sqrt(u**2+v**2)
v_norm=v/np.sqrt(u**2+v**2)

length_u=np.sqrt(u03043**2+v03043**2)

m.quiver(xcont[::,::3],ycont[::,::3],u_norm[::,::3]*length_u[::,::3],v_norm[::,::3]*length_u[::,::3],latlon=True,scale=300,headlength=3,headaxislength=2)

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax2b.set_title('(e)',x=-0.1,y=1.1,fontsize=8)

#mixed layer depth
m = Basemap(ax=ax2c,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,hmxl3043,latlon=True,cmap=colormap_hmxl,vmin=0,vmax=3300)
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax2c.set_title('(f)',x=-0.1,y=1.1,fontsize=8)

######################################################################################################################################
#cold mode
#SSS, ice margin
m = Basemap(ax=ax3a,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,sss3103,latlon=True,cmap=colormap_ferretrainbow,vmin=30,vmax=35)
m.contour(xcont,ycont,cong3103,latlon=True,colors='k',levels=[0.1])

a00,b00=m(1,70.8)
a0,b0=m(359,71.25)

a=[a00,a0]
b=[b00,b0]

m.plot(a,b,'k-')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax3a.set_ylabel('cold mode',rotation=0, size='large',x=-0.2,y=0.48, labelpad=90)
ax3a.set_title('(g)',x=-0.1,y=1.1,fontsize=8)

#surface velocity and eta
m = Basemap(ax=ax3b,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,eta3103,latlon=True,cmap=colormap_ferretrainbow,vmin=-350,vmax=160)

u_v=v03103*np.sin(xcontpi)
v_v=-v03103*np.cos(xcontpi)

u_u=-u03103*np.cos(ycontpi)*np.cos(xcontpi)
v_u=-u03103*np.cos(ycontpi)*np.sin(xcontpi)

u=u_v+u_u
v=v_u+v_v

u_norm=u/np.sqrt(u**2+v**2)
v_norm=v/np.sqrt(u**2+v**2)

length_u=np.sqrt(u03103**2+v03103**2)

m.quiver(xcont[::,::3],ycont[::,::3],u_norm[::,::3]*length_u[::,::3],v_norm[::,::3]*length_u[::,::3],latlon=True,scale=300,headlength=3,headaxislength=2)

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax3b.set_title('(h)',x=-0.1,y=1.1,fontsize=8)

#mixed layer depth
m = Basemap(ax=ax3c,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,hmxl3103,latlon=True,cmap=colormap_hmxl,vmin=0,vmax=3300)
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax3c.set_title('(i)',x=-0.1,y=1.1,fontsize=8)

######################################################################################################################################
#transition cold to warm
#SSS and ice margin
m = Basemap(ax=ax4a,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,sss3193,latlon=True,cmap=colormap_ferretrainbow,vmin=30,vmax=35)
m.contour(xcont,ycont,cong3193,latlon=True,colors='k',levels=[0.1])

a00,b00=m(359.5,84.8)
a0,b0=m(0.5,84.8)

a=[a00,a0]
b=[b00,b0]

m.plot(a,b,'k-')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax4a.set_ylabel('transition \n cold to warm',rotation=0, size='large',x=-0.2,y=0.48, labelpad=90)
ax4a.set_title('(j)',x=-0.1,y=1.1,fontsize=8)

fig.subplots_adjust(bottom=0.1)
cbar_ax = fig.add_axes([0.12, 0.05, 0.22, 0.02])

a=np.arange(30,35,0.05)
ticksbar=np.arange(30,35,1)
ticksbar=np.append(ticksbar,35)

cbar=fig.colorbar(cs,cax=cbar_ax,orientation='horizontal',boundaries=a,ticks=ticksbar,extend='both')
cbar.set_label('sea surface salinity [psu]',fontsize=10)
cbar_ax.tick_params(labelsize=8) 

#surface velocity and eta
m = Basemap(ax=ax4b,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,eta3193,latlon=True,cmap=colormap_ferretrainbow,vmin=-350,vmax=160)
u_v=v03193*np.sin(xcontpi)
v_v=-v03193*np.cos(xcontpi)

u_u=-u03193*np.cos(ycontpi)*np.cos(xcontpi)
v_u=-u03193*np.cos(ycontpi)*np.sin(xcontpi)

u=u_v+u_u
v=v_u+v_v

u_norm=u/np.sqrt(u**2+v**2)
v_norm=v/np.sqrt(u**2+v**2)

length_u=np.sqrt(u03193**2+v03193**2)

m.quiver(xcont[::,::3],ycont[::,::3],u_norm[::,::3]*length_u[::,::3],v_norm[::,::3]*length_u[::,::3],latlon=True,scale=300,headlength=3,headaxislength=2)

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax4b.set_title('(k)',x=-0.1,y=1.1,fontsize=8)

cbar_ax1 = fig.add_axes([0.405, 0.05, 0.22, 0.02])

a=np.arange(-350,170,10)
ticksbar=np.arange(-350,170,100)
ticksbar=np.append(ticksbar,170)

cbar=fig.colorbar(cs,cax=cbar_ax1, orientation='horizontal',boundaries=a,ticks=ticksbar,extend='both')
cbar_ax1.tick_params(labelsize=8) 
cbar.set_label('dynamic free surf. elevation [cm]',fontsize=10)

#mixed layer depth
m = Basemap(ax=ax4c,projection='npstere',boundinglat=40,lon_0=180,resolution='l',round=True)
cs = m.pcolor(x,y,hmxl3193,latlon=True,cmap=colormap_hmxl,vmin=0,vmax=3300)
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=8)

ax4c.set_title('(l)',x=-0.1,y=1.1,fontsize=8)

cbar_ax2 = fig.add_axes([0.69, 0.05, 0.22, 0.02])

a=np.arange(0,3300,10)
ticksbar=np.arange(-500,3300,1000)
ticksbar=np.append(ticksbar,3300)

cbar=fig.colorbar(cs,cax=cbar_ax2, orientation='horizontal',boundaries=a,ticks=ticksbar,extend='both')
cbar.set_label('mixed layer depth [m]',fontsize=10)
cbar_ax2.tick_params(labelsize=8) 

fig.savefig('4modes.pdf', format='pdf',bbox_inches='tight',dpi=300)             
###################################################################################################    
