#This script creates Fig. 4 in the Supplemenatry Material for 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid


degree_sign= u'\N{DEGREE SIGN}'

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]
lonmid=lonlatpsdata[66:82]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

#MOM grid for ice and continental contours
lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]

co2=[2000,1500,1000]
co2name=['2000','1500','1000']
   
namesp2h=np.array(['tsann'])       

Namevarlong=np.array(['surface air temperature, annual mean [°C]' ])

#create grid for maps
#atmosphere borders
lon2d, lat2d = np.meshgrid(lon,lat)
x=lon2d
y=lat2d

#ocean centers
lon2dmom, lat2dmom = np.meshgrid(lonmidmom,latmidmom)
xmom=lon2dmom
ymom=lat2dmom

minvar=-5
maxvar=5

Varco2=np.zeros((3,24,16))

#continent contours
Cont=np.zeros((48,96))
cont=np.loadtxt('ModelOutput_continents380.dat')
cont=cont.reshape((2,48,96))
cont=cont[0,:,:]#land ocean mask grid center
Cont[:,:]=cont

for j in range(len(co2name)):
    newdata=np.loadtxt('ModelOutput_p2h_'+co2name[j]+'.dat')
    newdata=newdata.reshape((24,16))
    Varco2[j,:,:]=newdata
         
fig,axes = plt.subplots(nrows=1, ncols=2,figsize=(7,3))
ax1=axes[0]
ax2=axes[1]

ax=[ax1,ax2]    

fig.subplots_adjust(left=0., right=1., bottom=0.1, top=0.9,wspace=0.2,hspace=0.4)    
  
#########################################################################################################################
m = Basemap(ax=ax1,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
#ax1.set_ylabel('(a) 1319 - 1315 W/m$^2$',rotation=0,size='large')
ax1.set_title('(a) 2000 ppm - 1500 ppm',x=0.5,y=1.1,fontsize=10)    

#surface air temperature
cs = m.pcolor(x,y,Varco2[0,:,:]-Varco2[1,:,:],latlon=True,cmap=plt.cm.seismic,vmin=minvar,vmax=maxvar)
#continent contour
m.contour(xmom,ymom,Cont[:,:],1,colors='k')
#########################################################################################################################
m = Basemap(ax=ax2,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
#ax2.set_ylabel('(b) 1321 - 1319 W/m$^2$',rotation=0, size='large',x=1,y=1.1, labelpad=60)
ax2.set_title('(b) 1000 ppm - 1500 ppm',x=0.5,y=1.1,fontsize=10)    

#surface air temperature
cs = m.pcolor(x,y,Varco2[2,:,:]-Varco2[1,:,:],latlon=True,cmap=plt.cm.seismic,vmin=minvar,vmax=maxvar)
#continent contour
m.contour(xmom,ymom,Cont[:,:],1,colors='k')
###########################################################################################################################
#color bar
fig.subplots_adjust(bottom=0.1)
cbar_ax = fig.add_axes([0.2, 0.06, 0.62, 0.04])
cbar_ax.set_aspect('auto')

ticksbar=np.arange(-5,5.1,1)


cbar=fig.colorbar(cs, cax=cbar_ax, orientation='horizontal',ticks=ticksbar,extend='both')            

cbar.set_label('Surface air temperature difference ['+degree_sign+'C]',fontsize=10)

 
fig.savefig('CO2_maps_diff.pdf', format='pdf',bbox_inches='tight') 
