#This script creates Fig. 7 in the Supplementary Material for 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid


degree_sign= u'\N{DEGREE SIGN}'

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]
lonmid=lonlatpsdata[66:82]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

#MOM grid for ice and continental contours
lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]

co2=[2000,1500,1000]
co2name=['2000','1500','1000']
   
namesp2h=np.array(['tsann'])       

Namevarlong=np.array(['surface air temperature, annual mean [°C]' ])

Var_mean=np.zeros((len(co2name),len(namesp2h)))

#create grid for maps
#atmosphere borders
lon2d, lat2d = np.meshgrid(lon,lat)
x=lon2d
y=lat2d

#ocean centers
lon2dmom, lat2dmom = np.meshgrid(lonmidmom,latmidmom)
xmom=lon2dmom
ymom=lat2dmom

minvar=-320
maxvar=320

#continent contours
Cont=np.zeros((48,96))
cont=np.loadtxt('ModelOutput_continents380.dat')
cont=cont.reshape((2,48,96))
cont=cont[0,:,:]#land ocean mask grid center
Cont[:,:]=cont

newdata=np.loadtxt('ModelOutput_p2h.dat')
newdata=newdata.reshape((2,24,16))
prc=newdata[0,:,:]
evp=newdata[1,:,:]
#########################################################################################################################
m = Basemap(projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    

#surface air temperature
cs = m.pcolor(x,y,evp-prc,latlon=True,cmap=plt.cm.seismic,vmin=minvar,vmax=maxvar)
#continent contour
m.contour(xmom,ymom,Cont[:,:],1,colors='k')

#color bar
ticksbar=np.arange(-320,321,80)
cbar=plt.colorbar(cs, orientation='horizontal',ticks=ticksbar,extend='both')            

cbar.set_label('evaporation minus precipitation [cm/year]',fontsize=10)

plt.savefig('eminp_maps_diff.pdf', format='pdf',bbox_inches='tight') 
